OC.L10N.register(
    "groupfolders",
    {
    "Denied (Inherited permission)" : "거부됨(권한 상속)",
    "Allowed (Inherited permission)" : "허용됨(권한 상속)",
    "Denied" : "거부됨",
    "Allowed" : "허용됨",
    "Access denied" : "접근이 거부됨",
    "Deny" : "거부",
    "Allow" : "허용",
    "Group" : "그룹",
    "Team" : "팀",
    "Read" : "읽기",
    "Write" : "쓰기",
    "Create" : "만들기",
    "Delete" : "삭제",
    "Share" : "공유",
    "You" : "나",
    "Remove access rule" : "접근 규칙 삭제",
    "Select a user or group" : "사용자 또는 그룹 선택",
    "Add group" : "그룹 추가",
    "Default" : "디폴트",
    "Delete \"{folderName}\"?" : "\"{folderName}\"을(를) 삭제하시겠습니까?",
    "Folder name" : "폴더 이름",
    "Quota" : "할당량",
    "Advanced Permissions" : "고급 권한",
    "Previous" : "이전",
    "Next" : "다음",
    "User" : "사용자",
    "Unknown" : "알 수 없음",
    "None" : "없음",
    "{size} used" : "{size} 사용됨",
    "Unset" : "설정 해제"
},
"nplurals=1; plural=0;");
